==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm5/lib/igc-tool-action-icon-button-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconButtonComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconButtonComponent, _super);
    function IgcToolActionIconButtonComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconButtonComponent.prototype.createImplementation = function () {
        return new ToolActionIconButton();
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconButtonComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.register = function () {
        if (!IgcToolActionIconButtonComponent._isElementRegistered) {
            IgcToolActionIconButtonComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "tooltipDelay", {
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.ib;
        },
        set: function (v) {
            this.i.ib = +v;
            this._a("tooltipDelay", this.i.ib);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualTooltipDelay", {
        /**
         * Gets the actual delay before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.ia;
        },
        set: function (v) {
            this.i.ia = +v;
            this._a("actualTooltipDelay", this.i.ia);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingLeft", {
        get: function () {
            return this.i.h3;
        },
        set: function (v) {
            this.i.h3 = +v;
            this._a("contentPaddingLeft", this.i.h3);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingLeft", {
        get: function () {
            return this.i.hz;
        },
        set: function (v) {
            this.i.hz = +v;
            this._a("actualContentPaddingLeft", this.i.hz);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingTop", {
        get: function () {
            return this.i.h5;
        },
        set: function (v) {
            this.i.h5 = +v;
            this._a("contentPaddingTop", this.i.h5);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingTop", {
        get: function () {
            return this.i.h1;
        },
        set: function (v) {
            this.i.h1 = +v;
            this._a("actualContentPaddingTop", this.i.h1);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingRight", {
        get: function () {
            return this.i.h4;
        },
        set: function (v) {
            this.i.h4 = +v;
            this._a("contentPaddingRight", this.i.h4);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingRight", {
        get: function () {
            return this.i.h0;
        },
        set: function (v) {
            this.i.h0 = +v;
            this._a("actualContentPaddingRight", this.i.h0);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingBottom", {
        get: function () {
            return this.i.h2;
        },
        set: function (v) {
            this.i.h2 = +v;
            this._a("contentPaddingBottom", this.i.h2);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingBottom", {
        get: function () {
            return this.i.hy;
        },
        set: function (v) {
            this.i.hy = +v;
            this._a("actualContentPaddingBottom", this.i.hy);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.cleanUp = function () {
        this.i.e3();
    };
    IgcToolActionIconButtonComponent.prototype.openSubMenu = function () {
        this.i.fy();
    };
    IgcToolActionIconButtonComponent.prototype.closeSubmenu = function () {
        this.i.e5();
    };
    IgcToolActionIconButtonComponent.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
}(IgcToolActionComponent));
export { IgcToolActionIconButtonComponent };

==> igniteui-webcomponents-layouts-5.1.0.tgz: package/esm5/lib/igc-tool-action-icon-button-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconButtonComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconButtonComponent, _super);
    function IgcToolActionIconButtonComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconButtonComponent.prototype.createImplementation = function () {
        return new ToolActionIconButton();
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconButtonComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.register = function () {
        if (!IgcToolActionIconButtonComponent._isElementRegistered) {
            IgcToolActionIconButtonComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "tooltipDelay", {
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.ic;
        },
        set: function (v) {
            this.i.ic = +v;
            this._a("tooltipDelay", this.i.ic);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualTooltipDelay", {
        /**
         * Gets the actual delay before the tooltip is displayed (in milliseconds).
        */
        get: function () {
            return this.i.ib;
        },
        set: function (v) {
            this.i.ib = +v;
            this._a("actualTooltipDelay", this.i.ib);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingLeft", {
        get: function () {
            return this.i.h4;
        },
        set: function (v) {
            this.i.h4 = +v;
            this._a("contentPaddingLeft", this.i.h4);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingLeft", {
        get: function () {
            return this.i.h0;
        },
        set: function (v) {
            this.i.h0 = +v;
            this._a("actualContentPaddingLeft", this.i.h0);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingTop", {
        get: function () {
            return this.i.h6;
        },
        set: function (v) {
            this.i.h6 = +v;
            this._a("contentPaddingTop", this.i.h6);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingTop", {
        get: function () {
            return this.i.h2;
        },
        set: function (v) {
            this.i.h2 = +v;
            this._a("actualContentPaddingTop", this.i.h2);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingRight", {
        get: function () {
            return this.i.h5;
        },
        set: function (v) {
            this.i.h5 = +v;
            this._a("contentPaddingRight", this.i.h5);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingRight", {
        get: function () {
            return this.i.h1;
        },
        set: function (v) {
            this.i.h1 = +v;
            this._a("actualContentPaddingRight", this.i.h1);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "contentPaddingBottom", {
        get: function () {
            return this.i.h3;
        },
        set: function (v) {
            this.i.h3 = +v;
            this._a("contentPaddingBottom", this.i.h3);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconButtonComponent.prototype, "actualContentPaddingBottom", {
        get: function () {
            return this.i.hz;
        },
        set: function (v) {
            this.i.hz = +v;
            this._a("actualContentPaddingBottom", this.i.hz);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconButtonComponent.prototype.cleanUp = function () {
        this.i.e3();
    };
    IgcToolActionIconButtonComponent.prototype.openSubMenu = function () {
        this.i.fy();
    };
    IgcToolActionIconButtonComponent.prototype.closeSubmenu = function () {
        this.i.e5();
    };
    IgcToolActionIconButtonComponent.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
}(IgcToolActionComponent));
export { IgcToolActionIconButtonComponent };
